Struct frame::prelude::frame_system::offchain::Signer
pub struct Signer<T, C, X = ForAny>where
T: SigningTypes,
C: AppCrypto<<T as SigningTypes>::Public, <T as SigningTypes>::Signature>,{ /* private fields */ }Expand description
Provides an implementation for signing transaction payloads.
Keys used for signing are defined when instantiating the signer object. Signing can be done using:
- All supported keys in the keystore
- Any of the supported keys in the keystore
- An intersection of in-keystore keys and the list of provided keys
The signer is then able to:
- Submit a unsigned transaction with a signed payload
- Submit a signed transaction
Implementations
impl<T, C, X> Signer<T, C, X>where
T: SigningTypes,
C: AppCrypto<<T as SigningTypes>::Public, <T as SigningTypes>::Signature>,
impl<T, C, X> Signer<T, C, X>where T: SigningTypes, C: AppCrypto<<T as SigningTypes>::Public, <T as SigningTypes>::Signature>,
pub fn all_accounts() -> Signer<T, C, ForAll>
pub fn all_accounts() -> Signer<T, C, ForAll>
Use all available keys for signing.
pub fn any_account() -> Signer<T, C, ForAny>
pub fn any_account() -> Signer<T, C, ForAny>
Use any of the available keys for signing.
pub fn with_filter(
self,
accounts: Vec<<T as SigningTypes>::Public, Global>
) -> Signer<T, C, X>
pub fn with_filter( self, accounts: Vec<<T as SigningTypes>::Public, Global> ) -> Signer<T, C, X>
Use provided accounts for signing.
Note that not all keys will be necessarily used. The provided vector of accounts will be intersected with the supported keys in the keystore and the resulting list will be used for signing.
pub fn accounts_from_keys<'a>(
&'a self
) -> Box<dyn Iterator<Item = Account<T>> + 'a, Global>
pub fn accounts_from_keys<'a>( &'a self ) -> Box<dyn Iterator<Item = Account<T>> + 'a, Global>
Return a vector of the intersection between
all available accounts and the provided accounts
in with_filter. If no accounts are provided,
use all accounts by default.
pub fn keystore_accounts() -> impl Iterator<Item = Account<T>>
pub fn keystore_accounts() -> impl Iterator<Item = Account<T>>
Return all available accounts in keystore.