pub trait SendSignedTransaction<T, C, LocalCall>where
    T: SigningTypes + CreateSignedTransaction<LocalCall>,
    C: AppCrypto<<T as SigningTypes>::Public, <T as SigningTypes>::Signature>,{
    type Result;

    // Required method
    fn send_signed_transaction(
        &self,
        f: impl Fn(&Account<T>) -> LocalCall
    ) -> Self::Result;

    // Provided method
    fn send_single_signed_transaction(
        &self,
        account: &Account<T>,
        call: LocalCall
    ) -> Option<Result<(), ()>> { ... }
}
Submit a signed transaction to the transaction pool.

Required Associated Types

type Result

A submission result.

This should contain an indication of success and the account that was used for signing.

Required Methods

fn send_signed_transaction( &self, f: impl Fn(&Account<T>) -> LocalCall ) -> Self::Result

Submit a signed transaction to the local pool.

Given f closure will be called for every requested account and expects a Call object to be returned. The call is then wrapped into a transaction (see #CreateSignedTransaction), signed and submitted to the pool.

Provided Methods

fn send_single_signed_transaction( &self, account: &Account<T>, call: LocalCall ) -> Option<Result<(), ()>>

Wraps the call into transaction, signs using given account and submits to the pool.

Implementors



impl<T, C, LocalCall> SendSignedTransaction<T, C, LocalCall> for Signer<T, C, ForAll>where T: SigningTypes + CreateSignedTransaction<LocalCall>, C: AppCrypto<<T as SigningTypes>::Public, <T as SigningTypes>::Signature>,



type Result = Vec<(Account<T>, Result<(), ()>), Global>



impl<T, C, LocalCall> SendSignedTransaction<T, C, LocalCall> for Signer<T, C, ForAny>where T: CreateSignedTransaction<LocalCall> + SigningTypes, C: AppCrypto<<T as SigningTypes>::Public, <T as SigningTypes>::Signature>,



type Result = Option<(Account<T>, Result<(), ()>)>