pub trait SendTransactionTypes<LocalCall> {
    type Extrinsic: Extrinsic<Call = Self::OverarchingCall> + Encode;
    type OverarchingCall: From<LocalCall> + Encode;
}
A definition of types required to submit transactions from within the runtime.

Required Associated Types

type Extrinsic: Extrinsic<Call = Self::OverarchingCall> + Encode

The extrinsic type expected by the runtime.

type OverarchingCall: From<LocalCall> + Encode

The runtime’s call type.

This has additional bound to be able to be created from pallet-local Call types.

Implementors